@@ -39,10 +39,3 @@ communicate_summary <- function(changed, ruler_width) {
     cli::cat_rule(width = max(40L, ruler_width))
   }
 }
-
-
-assert_data.tree_installation <- function() {
-  if (!is_installed("data.tree")) {
-    abort("The package data.tree needs to be installed for this functionality.")
-  }
-}
