@@ -47,7 +47,7 @@ create_tree_from_pd_with_default_style_attributes <- function(pd,
 #' }
 #' @keywords internal
 create_node_from_nested_root <- function(pd_nested, structure_only) {
-  assert_data.tree_installation()
+  check_installed("data.tree")
   name <- if (structure_only) {
     "Hierarchical structure"
   } else {
