@@ -379,5 +379,5 @@ skip_during_parallel <- function() {
   Sys.getenv("STYLER_TEST_IS_TRULY_PARALLEL", TRUE) %>%
     toupper() %>%
     as.logical() %>%
-    testthat::skip_if()
+    testthat::skip_if("Running in parallel")
 }
