@@ -98,3 +98,17 @@ call(
   {{ x }},
   {{ y}} := 3, f(bk)
 )
+
+call({{
+  #
+  1
+}})
+
+call({{
+  #
+}})
+
+
+{{
+  #
+}}
