@@ -1,4 +1,4 @@
-context("rmd")
+
 
 test_that("can style .Rmd files", {
   expect_warning(test_collection("rmd", "simple",
@@ -48,4 +48,23 @@ test_that("can style .Rmd files", {
     filetype = "Rmd",
     write_tree = FALSE
   ), NA)
+  expect_warning(test_collection("rmd", "random7",
+    transformer = transform_mixed,
+    transformer_fun = style_text,
+    filetype = "Rmd",
+    write_tree = FALSE
+  ), NA)
+})
+
+
+test_that("code chunks without code are returned as zero lines", {
+  local_test_setup()
+  t <- make_transformer(transformers = tidyverse_style())
+  lines <- ""
+
+  expect_equal(transform_mixed_non_empty("", t), character(0))
+  expect_equal(transform_mixed_non_empty("\n", t), character(0))
+  expect_equal(transform_mixed_non_empty(c("", ""), t), character(0))
+  expect_equal(transform_mixed_non_empty(c("", " "), t), character(0))
+  expect_equal(transform_mixed_non_empty(c("\t", ""), t), character(0))
 })
